@@ -32,6 +32,7 @@
 
 #include <QHash>
 #include <QObject>
+#include <QHostAddress>
 
 #include "base/http/irequesthandler.h"
 #include "base/http/responsebuilder.h"
@@ -51,7 +52,7 @@ namespace BitTorrent
 {
     struct Peer
     {
-        QString ip;
+        QHostAddress ip;
         QByteArray peerId;
         int port;
 
@@ -90,9 +91,9 @@ namespace BitTorrent
 
     private:
         void respondToAnnounceRequest();
-        void registerPeer(const TrackerAnnounceRequest &annonceReq);
-        void unregisterPeer(const TrackerAnnounceRequest &annonceReq);
-        void replyWithPeerList(const TrackerAnnounceRequest &annonceReq);
+        void registerPeer(const TrackerAnnounceRequest &announceReq);
+        void unregisterPeer(const TrackerAnnounceRequest &announceReq);
+        void replyWithPeerList(const TrackerAnnounceRequest &announceReq);
 
         Http::Server *m_server;
         TorrentList m_torrents;
