@@ -1,6 +1,6 @@
 /*
- * Bittorrent Client using Qt4 and libtorrent.
- * Copyright (C) 2011  Christophe Dumez
+ * Bittorrent Client using Qt and libtorrent.
+ * Copyright (C) 2011  Christophe Dumez <chris@qbittorrent.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,26 +24,23 @@
  * modify file(s), you may extend this exception to your version of the file(s),
  * but you are not obligated to do so. If you do not wish to do so, delete this
  * exception statement from your version.
- *
- * Contact : chris@qbittorrent.org
  */
+
 #ifndef LOGLISTWIDGET_H
 #define LOGLISTWIDGET_H
 
 #include <QListWidget>
 #include "base/logger.h"
 
-QT_BEGIN_NAMESPACE
 class QKeyEvent;
-QT_END_NAMESPACE
 
-class LogListWidget: public QListWidget
+class LogListWidget : public QListWidget
 {
     Q_OBJECT
 
 public:
     // -1 is the portable way to have all the bits set
-    explicit LogListWidget(int maxLines, const Log::MsgTypes &types = Log::ALL, QWidget *parent = 0);
+    explicit LogListWidget(int maxLines, const Log::MsgTypes &types = Log::ALL, QWidget *parent = nullptr);
     void showMsgTypes(const Log::MsgTypes &types);
 
 public slots:
@@ -53,7 +50,7 @@ protected slots:
     void copySelection();
 
 protected:
-    void keyPressEvent(QKeyEvent *event);
+    void keyPressEvent(QKeyEvent *event) override;
 
 private:
     int m_maxLines;
