@@ -34,7 +34,6 @@
 #include <stdexcept>
 #include <vector>
 
-#include <QCoreApplication>
 #include <QDateTime>
 #include <QDebug>
 #include <QFile>
@@ -60,6 +59,7 @@
 #include "api/authcontroller.h"
 #include "api/logcontroller.h"
 #include "api/rsscontroller.h"
+#include "api/searchcontroller.h"
 #include "api/synccontroller.h"
 #include "api/torrentscontroller.h"
 #include "api/transfercontroller.h"
@@ -91,46 +91,6 @@ namespace
         return ret;
     }
 
-    void translateDocument(const QString &locale, QString &data)
-    {
-        const QRegularExpression regex("QBT_TR\\((([^\\)]|\\)(?!QBT_TR))+)\\)QBT_TR(\\[CONTEXT=([a-zA-Z_][a-zA-Z0-9_]*)\\])");
-        const QRegularExpression mnemonic("\\(?&([a-zA-Z]?\\))?");
-
-        const bool isTranslationNeeded = !locale.startsWith("en")
-            || locale.startsWith("en_AU") || locale.startsWith("en_GB");
-
-        int i = 0;
-        bool found = true;
-        while (i < data.size() && found) {
-            QRegularExpressionMatch regexMatch;
-            i = data.indexOf(regex, i, &regexMatch);
-            if (i >= 0) {
-                const QString word = regexMatch.captured(1);
-                const QString context = regexMatch.captured(4);
-
-                QString translation = isTranslationNeeded
-                    ? qApp->translate(context.toUtf8().constData(), word.toUtf8().constData(), nullptr, 1)
-                    : word;
-
-                // Remove keyboard shortcuts
-                translation.remove(mnemonic);
-
-                // Use HTML code for quotes to prevent issues with JS
-                translation.replace('\'', "&#39;");
-                translation.replace('\"', "&#34;");
-
-                data.replace(i, regexMatch.capturedLength(), translation);
-                i += translation.length();
-            }
-            else {
-                found = false; // no more translatable strings
-            }
-
-            data.replace(QLatin1String("${LANG}"), locale.left(2));
-            data.replace(QLatin1String("${VERSION}"), QBT_VERSION);
-        }
-    }
-
     inline QUrl urlFromHostHeader(const QString &hostHeader)
     {
         if (!hostHeader.contains(QLatin1String("://")))
@@ -162,6 +122,7 @@ WebApplication::WebApplication(QObject *parent)
     registerAPIController(QLatin1String("auth"), new AuthController(this, this));
     registerAPIController(QLatin1String("log"), new LogController(this, this));
     registerAPIController(QLatin1String("rss"), new RSSController(this, this));
+    registerAPIController(QLatin1String("search"), new SearchController(this, this));
     registerAPIController(QLatin1String("sync"), new SyncController(this, this));
     registerAPIController(QLatin1String("torrents"), new TorrentsController(this, this));
     registerAPIController(QLatin1String("transfer"), new TransferController(this, this));
@@ -234,6 +195,42 @@ void WebApplication::sendWebUIFile()
     sendFile(localPath);
 }
 
+void WebApplication::translateDocument(QString &data)
+{
+    const QRegularExpression regex("QBT_TR\\((([^\\)]|\\)(?!QBT_TR))+)\\)QBT_TR\\[CONTEXT=([a-zA-Z_][a-zA-Z0-9_]*)\\]");
+
+    int i = 0;
+    bool found = true;
+    while (i < data.size() && found) {
+        QRegularExpressionMatch regexMatch;
+        i = data.indexOf(regex, i, &regexMatch);
+        if (i >= 0) {
+            const QString sourceText = regexMatch.captured(1);
+            const QString context = regexMatch.captured(3);
+
+            const QString loadedText = m_translationFileLoaded
+                ? m_translator.translate(context.toUtf8().constData(), sourceText.toUtf8().constData())
+                : QString();
+            // `loadedText` is empty when translation is not provided
+            // it should fallback to `sourceText`
+            QString translation = loadedText.isEmpty() ? sourceText : loadedText;
+
+            // Use HTML code for quotes to prevent issues with JS
+            translation.replace('\'', "&#39;");
+            translation.replace('\"', "&#34;");
+
+            data.replace(i, regexMatch.capturedLength(), translation);
+            i += translation.length();
+        }
+        else {
+            found = false; // no more translatable strings
+        }
+
+        data.replace(QLatin1String("${LANG}"), m_currentLocale.left(2));
+        data.replace(QLatin1String("${VERSION}"), QBT_VERSION);
+    }
+}
+
 WebSession *WebApplication::session()
 {
     return m_currentSession;
@@ -416,19 +413,34 @@ void WebApplication::doProcessRequest()
 
 void WebApplication::configure()
 {
-    const auto pref = Preferences::instance();
+    const auto *pref = Preferences::instance();
 
+    const bool isAltUIUsed = pref->isAltWebUiEnabled();
     const QString rootFolder = Utils::Fs::expandPathAbs(
-                !pref->isAltWebUiEnabled() ? WWW_FOLDER : pref->getWebUiRootFolder());
-    if (rootFolder != m_rootFolder) {
-        m_translatedFiles.clear();
+                !isAltUIUsed ? WWW_FOLDER : pref->getWebUiRootFolder());
+    if ((isAltUIUsed != m_isAltUIUsed) || (rootFolder != m_rootFolder)) {
+        m_isAltUIUsed = isAltUIUsed;
         m_rootFolder = rootFolder;
+        m_translatedFiles.clear();
+        if (!m_isAltUIUsed)
+            LogMsg(tr("Using built-in Web UI."));
+        else
+            LogMsg(tr("Using custom Web UI. Location: \"%1\".").arg(m_rootFolder));
     }
 
     const QString newLocale = pref->getLocale();
     if (m_currentLocale != newLocale) {
         m_currentLocale = newLocale;
         m_translatedFiles.clear();
+
+        m_translationFileLoaded = m_translator.load(m_rootFolder + QLatin1String("/translations/webui_") + newLocale);
+        if (m_translationFileLoaded) {
+            LogMsg(tr("Web UI translation for selected locale (%1) has been successfully loaded.")
+                   .arg(newLocale));
+        }
+        else {
+            LogMsg(tr("Couldn't load Web UI translation for selected locale (%1).").arg(newLocale), Log::WARNING);
+        }
     }
 
     m_isLocalAuthEnabled = pref->isWebUiLocalAuthEnabled();
@@ -440,7 +452,15 @@ void WebApplication::configure()
 
     m_isClickjackingProtectionEnabled = pref->isWebUiClickjackingProtectionEnabled();
     m_isCSRFProtectionEnabled = pref->isWebUiCSRFProtectionEnabled();
+    m_isHostHeaderValidationEnabled = pref->isWebUIHostHeaderValidationEnabled();
     m_isHttpsEnabled = pref->isWebUiHttpsEnabled();
+
+    m_contentSecurityPolicy =
+        (m_isAltUIUsed
+            ? QLatin1String("")
+            : QLatin1String("default-src 'self'; style-src 'self' 'unsafe-inline'; img-src 'self' data:; script-src 'self' 'unsafe-inline'; object-src 'none'; form-action 'self';"))
+        + (m_isClickjackingProtectionEnabled ? QLatin1String(" frame-ancestors 'self';") : QLatin1String(""))
+        + (m_isHttpsEnabled ? QLatin1String(" upgrade-insecure-requests;") : QLatin1String(""));
 }
 
 void WebApplication::registerAPIController(const QString &scope, APIController *controller)
@@ -490,7 +510,7 @@ void WebApplication::sendFile(const QString &path)
     // Translate the file
     if (isTranslatable) {
         QString dataStr {data};
-        translateDocument(m_currentLocale, dataStr);
+        translateDocument(dataStr);
         data = dataStr.toUtf8();
 
         m_translatedFiles[path] = {data, lastModified}; // caching translated file
@@ -509,7 +529,7 @@ Http::Response WebApplication::processRequest(const Http::Request &request, cons
     if (m_request.method == Http::METHOD_GET) {
         // Parse GET parameters
         using namespace Utils::ByteArray;
-        for (const QByteArray &param : copyAsConst(splitToViews(m_request.query, "&"))) {
+        for (const QByteArray &param : asConst(splitToViews(m_request.query, "&"))) {
             const int sepPos = param.indexOf('=');
             if (sepPos <= 0) continue; // ignores params without name
 
@@ -530,7 +550,7 @@ Http::Response WebApplication::processRequest(const Http::Request &request, cons
     try {
         // block suspicious requests
         if ((m_isCSRFProtectionEnabled && isCrossSiteRequest(m_request))
-            || !validateHostHeader(m_domainList)) {
+            || (m_isHostHeaderValidationEnabled && !validateHostHeader(m_domainList))) {
             throw UnauthorizedHTTPError();
         }
 
@@ -543,19 +563,17 @@ Http::Response WebApplication::processRequest(const Http::Request &request, cons
             print(error.message(), Http::CONTENT_TYPE_TXT);
     }
 
-    header(Http::HEADER_X_XSS_PROTECTION, "1; mode=block");
-    header(Http::HEADER_X_CONTENT_TYPE_OPTIONS, "nosniff");
+    header(QLatin1String(Http::HEADER_X_XSS_PROTECTION), QLatin1String("1; mode=block"));
+    header(QLatin1String(Http::HEADER_X_CONTENT_TYPE_OPTIONS), QLatin1String("nosniff"));
 
-    QString csp = QLatin1String("default-src 'self'; style-src 'self' 'unsafe-inline'; img-src 'self' data:; script-src 'self' 'unsafe-inline'; object-src 'none'; form-action 'self';");
-    if (m_isClickjackingProtectionEnabled) {
-        header(Http::HEADER_X_FRAME_OPTIONS, "SAMEORIGIN");
-        csp += QLatin1String(" frame-ancestors 'self';");
-    }
-    if (m_isHttpsEnabled) {
-        csp += QLatin1String(" upgrade-insecure-requests;");
-    }
+    if (m_isClickjackingProtectionEnabled)
+        header(QLatin1String(Http::HEADER_X_FRAME_OPTIONS), QLatin1String("SAMEORIGIN"));
 
-    header(Http::HEADER_CONTENT_SECURITY_POLICY, csp);
+    if (!m_isAltUIUsed)
+        header(QLatin1String(Http::HEADER_REFERRER_POLICY), QLatin1String("same-origin"));
+
+    if (!m_contentSecurityPolicy.isEmpty())
+        header(QLatin1String(Http::HEADER_CONTENT_SECURITY_POLICY), m_contentSecurityPolicy);
 
     return response();
 }
@@ -633,7 +651,8 @@ void WebApplication::sessionStart()
 
     // remove outdated sessions
     const qint64 now = QDateTime::currentMSecsSinceEpoch() / 1000;
-    foreach (const auto session, m_sessions) {
+    const QMap<QString, WebSession *> sessionsCopy {m_sessions};
+    for (const auto session : sessionsCopy) {
         if ((now - session->timestamp()) > INACTIVE_TIME)
             delete m_sessions.take(session->id());
     }
@@ -644,7 +663,10 @@ void WebApplication::sessionStart()
     QNetworkCookie cookie(C_SID, m_currentSession->id().toUtf8());
     cookie.setHttpOnly(true);
     cookie.setPath(QLatin1String("/"));
-    header(Http::HEADER_SET_COOKIE, cookie.toRawForm());
+    QByteArray cookieRawForm = cookie.toRawForm();
+    if (m_isCSRFProtectionEnabled)
+        cookieRawForm.append("; SameSite=Strict");
+    header(Http::HEADER_SET_COOKIE, cookieRawForm);
 }
 
 void WebApplication::sessionEnd()
