@@ -23,7 +23,7 @@ if (typeof localStorage == 'undefined') {
 }
 
 function getLocalStorageItem(name, defaultVal) {
-    val = localStorage.getItem(name);
+    var val = localStorage.getItem(name);
     if (val === null || val === undefined)
         val = defaultVal;
     return val;
@@ -59,12 +59,20 @@ initializeWindows = function() {
 
     addClickEvent('download', function(e) {
         new Event(e).stop();
+        showDownloadPage();
+    });
+
+    showDownloadPage = function(urls) {
         var id = 'downloadPage';
+        var contentUrl = 'download.html';
+        if (urls && urls.length)
+            contentUrl += '?urls=' + urls.join("|");
+
         new MochaUI.Window({
             id: id,
             title: "QBT_TR(Download from URLs)QBT_TR[CONTEXT=downloadFromURL]",
             loadMethod: 'iframe',
-            contentURL: 'download.html',
+            contentURL: contentUrl,
             addClass: 'windowFrame', // fixes iframe scrolling on iOS Safari
             scrollbars: true,
             maximizable: false,
@@ -78,7 +86,7 @@ initializeWindows = function() {
             }
         });
         updateMainData();
-    });
+    };
 
     addClickEvent('preferences', function(e) {
         new Event(e).stop();
@@ -725,7 +733,7 @@ initializeWindows = function() {
             new Request({
                 url: 'api/v2/app/shutdown',
                 onSuccess: function() {
-                    document.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\"><html xmlns=\"http://www.w3.org/1999/xhtml\"><head><title>QBT_TR(qBittorrent has been shutdown.)QBT_TR[CONTEXT=HttpServer]</title><style type=\"text/css\">body { text-align: center; }</style></head><body><h1>QBT_TR(qBittorrent has been shutdown.)QBT_TR[CONTEXT=HttpServer]</h1></body></html>");
+                    document.write('<!doctype html><html lang="${LANG}"><head> <meta charset="utf-8"> <title>QBT_TR(qBittorrent has been shutdown)QBT_TR[CONTEXT=HttpServer]</title></head><body> <h1 style="text-align: center;">QBT_TR(qBittorrent has been shutdown)QBT_TR[CONTEXT=HttpServer]</h1></body></html>');
                     stop();
                 }
             }).send();
